==> image-data-domain-0.0.96-sources.jar: com/xforceplus/elephant/entity/BaseBill.java <==
package com.xforceplus.elephant.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-01
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class BaseBill implements Serializable {

  private static final long serialVersionUID=1L;

  private Long imageId;

  private String batchNo;

  private String billTypeCode;

  private String billCode;

  private BigDecimal billAmountWithTax;

  private BigDecimal billTaxAmount;

  private BigDecimal billAmountWithoutTax;

  private String billCreateUser;

  private LocalDateTime billCreateTime;

  private Long scanUserId;

  private String scanUserName;

  private LocalDateTime scanCreateTime;

  private String packageCode;

  private String logisticsStatus;

  private LocalDateTime logisticsTime;

  private String signStatus;

  private LocalDateTime signTime;

  private String isPublic;

  private String logisticRemark;

  private String hangType;

  private String hangReason;

  private String backType;

  private String backReason;

  private String billDataStatus;

  private LocalDateTime billDataTime;

  private String verifyStatus;

  private LocalDateTime verifyTime;

  private Long ticketCount;

  private Long imageCount;

  private Long exceptionCount;

  private Long warningCount;

  private String isException;

  private String exceptionInfo;

  private String systemOrig;

  private String isSecret;

  private String backRemark;

  private String unqualityType;

  private String unqualityReason;

  private String verifyHangType;

  private String verifyHangReason;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String isPrepayment;

  private String extFields;

  private String extStatus;

  private String prepaymentStatus;

  private LocalDateTime prepaymentTime;

  private String createUserCode;

  private String sellerTaxNo;

  private String sellerName;

  private String purchaserTaxNo;

  private String purchaserName;

  private String serialNumber;

  private String billCheckStatus;

  private String purchaserCode;

  private LocalDateTime billCheckTime;

  private String remark;

  private String sellerCode;

  private String tenantCode;

  private String backOrig;

  private String calculateStatus;

  private String isWarning;

  private String warningInfo;

  private String relWarningInfo;

  private String relExceptionInfo;




        }

==> image-data-domain-0.0.124-sources.jar: com/xforceplus/elephant/entity/BaseBill.java <==
package com.xforceplus.elephant.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-31
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class BaseBill implements Serializable {

  private static final long serialVersionUID=1L;

  private Long imageId;

  private String batchNo;

  private String billTypeCode;

  private String billCode;

  private BigDecimal billAmountWithTax;

  private BigDecimal billTaxAmount;

  private BigDecimal billAmountWithoutTax;

  private String billCreateUser;

  private LocalDateTime billCreateTime;

  private Long scanUserId;

  private String scanUserName;

  private LocalDateTime scanCreateTime;

  private String packageCode;

  private String logisticsStatus;

  private LocalDateTime logisticsTime;

  private String signStatus;

  private LocalDateTime signTime;

  private String isPublic;

  private String logisticRemark;

  private String hangType;

  private String hangReason;

  private String backType;

  private String backReason;

  private String billDataStatus;

  private LocalDateTime billDataTime;

  private String verifyStatus;

  private LocalDateTime verifyTime;

  private Long ticketCount;

  private Long imageCount;

  private Long exceptionCount;

  private Long warningCount;

  private String isException;

  private String exceptionInfo;

  private String systemOrig;

  private String isSecret;

  private String backRemark;

  private String unqualityType;

  private String unqualityReason;

  private String verifyHangType;

  private String verifyHangReason;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private String isPrepayment;

  private String extFields;

  private String extStatus;

  private String prepaymentStatus;

  private LocalDateTime prepaymentTime;

  private String createUserCode;

  private String sellerTaxNo;

  private String sellerName;

  private String purchaserTaxNo;

  private String purchaserName;

  private String serialNumber;

  private String billCheckStatus;

  private String purchaserCode;

  private LocalDateTime billCheckTime;

  private String remark;

  private String sellerCode;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  private String backOrig;

  private String calculateStatus;

  private String isWarning;

  private String warningInfo;

  private String relWarningInfo;

  private String relExceptionInfo;

  private String purchaserNo;

  private String backUser;

  private String testDe;

  private String reserved1;

  private String reserved2;

  private String reserved3;

  private String isCommit;

  private Long commitUserId;

  private String commitUserName;

  private LocalDateTime commitTime;




        }
